from sphinx.locale import _
from docutils import nodes
from docutils.parsers.rst import Directive, directives

class card(nodes.General, nodes.Element):
    pass

class CardDirective(Directive):

    # defines the parameter the directive expects
    # directives.unchanged means you get the raw value from RST
    required_arguments = 0
    optional_arguments = 0
    final_argument_whitespace = True
    option_spec = {'title': directives.unchanged,
                   'link': directives.unchanged,
                   'is_head': directives.unchanged}
    has_content = True
    add_index = False

    def run(self):
        # gives you access to the options of the directive
        options = self.options

        cid = nodes.make_id("card-{}".format(options['title']))

        classes = ['mx-card']
        if options.get('is_head', 'False').lower() == 'true':
            classes.append('head-card')
        container = nodes.container(ids=[cid], classes=classes)

        container += nodes.inline('', options['title'], classes=['mx-card-title'])
        link = options.get('link')
        if link:
            container += nodes.inline('', link, classes=['mx-card-link'])

        para = nodes.paragraph(classes=['mx-card-text'])
        self.state.nested_parse(self.content, self.content_offset, para)
        container += para

        # we return the result
        return [container]



from os import path
from .card import CardDirective

__version__ = '0.3.14'
__version_full__ = __version__

package_dir = path.dirname(path.abspath(__file__))

def get_path():
    return package_dir

def setup(app):
    app.add_html_theme('mxtheme', package_dir)
    return {'version': __version__, 'parallel_read_safe': True}



from setuptools import setup
from mxtheme import __version__

setup(
    name = 'mxtheme',
    version = __version__,
    author = 'Mu Li',
    author_email= '',
    url="https://github.com/mli/mx-theme",
    description='A Sphinx theme based on Material Design, adapted from sphinx_materialdesign_theme',
    packages = ['mxtheme'],
    include_package_data=True,
    license= 'MIT License',
    entry_points = {
        'sphinx.html_themes': [
            'mxtheme = mxtheme',
        ]
    },
)
